@@ -119,6 +119,12 @@ class GitBranch(Branch):
         self.tag = tag
         self.unmirrored_module = unmirrored_module
 
+    def get_module_basename(self):
+        name = os.path.basename(self.module)
+        if name.endswith('.git'):
+            name = name[:-4]
+        return name
+ 
     def srcdir(self):
         path_elements = [self.checkoutroot]
         if self.checkoutdir:
@@ -263,6 +269,18 @@ class GitBranch(Branch):
             buildscript.execute(['git', 'stash', 'save', 'jhbuild-stash'],
                     **git_extra_args)
 
+        current_branch = self.get_current_branch()
+        if current_branch is None:
+            # things are getting out of hand, check the git repository is
+            # correct
+            try:
+                get_output(['git', 'show'], **git_extra_args)
+            except CommandError:
+                raise CommandError(_('Failed to update module (corrupt .git?)'))
+
+        if current_branch not in ('(no branch)', None):
+            buildscript.execute(['git', 'pull', '--rebase'], **git_extra_args)
+
         would_be_branch = self.branch or 'master'
         if self.tag:
             buildscript.execute(['git', 'checkout', self.tag], **git_extra_args)
@@ -283,10 +301,6 @@ class GitBranch(Branch):
                             would_be_branch, 'origin/' + would_be_branch],
                             **git_extra_args)
 
-        current_branch = self.get_current_branch()
-        if current_branch not in ('(no branch)', None):
-            buildscript.execute(['git', 'pull', '--rebase'], **git_extra_args)
-
         if stashed:
             # git stash pop was introduced in 1.5.5, 
             if check_version(['git', '--version'],
